# Processing Module / 処理モジュール

The `wandas.processing` module provides various processing capabilities for audio data.
`wandas.processing` モジュールは、オーディオデータに対する様々な処理機能を提供します。

## Base Processing / 基本処理

Provides basic processing operations.
基本的な処理操作を提供します。

::: wandas.processing.base

## Effects / エフェクト

Provides audio effect processing.
オーディオエフェクト処理を提供します。

::: wandas.processing.effects

## Filters / フィルター

Provides various audio filter processing.
様々なオーディオフィルター処理を提供します。

::: wandas.processing.filters

## Spectral Processing / スペクトル処理

Provides spectral analysis and processing capabilities.
スペクトル解析と処理機能を提供します。

::: wandas.processing.spectral

## Statistical Processing / 統計処理

Provides statistical analysis functions for audio data.
オーディオデータの統計分析機能を提供します。

::: wandas.processing.stats

## Temporal Processing / 時間領域処理

Provides time-domain processing capabilities.
時間領域の処理機能を提供します。

::: wandas.processing.temporal
